@@ -25,9 +25,10 @@
 #ifndef GNOME_VFS_MIME_HANDLERS_H
 #define GNOME_VFS_MIME_HANDLERS_H
 
-#include <glib.h>
-#include <liboaf/liboaf.h>
-#include <libgnomevfs/gnome-vfs-types.h> /* for GnomeVFSResult */
+#include <libgnomevfs/gnome-vfs-result.h>
+#include <bonobo-activation/bonobo-activation.h>
+
+G_BEGIN_DECLS
 
 typedef enum {
 	GNOME_VFS_MIME_ACTION_TYPE_NONE,
@@ -35,19 +36,26 @@ typedef enum {
 	GNOME_VFS_MIME_ACTION_TYPE_COMPONENT
 } GnomeVFSMimeActionType;
 
+typedef enum {
+	GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_URIS,
+	GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_PATHS,
+	GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_URIS_FOR_NON_FILES
+} GnomeVFSMimeApplicationArgumentType;
+
 typedef struct {
 	char *id;
 	char *name;
 	char *command;
 	gboolean can_open_multiple_files;
-	gboolean can_open_uris;
+	GnomeVFSMimeApplicationArgumentType expects_uris;
+	GList *supported_uri_schemes;
 	gboolean requires_terminal;
 } GnomeVFSMimeApplication;
 
 typedef struct {
 	GnomeVFSMimeActionType action_type;
 	union {
-		OAF_ServerInfo *component;
+		Bonobo_ServerInfo *component;
 		void *dummy_component;
 		GnomeVFSMimeApplication *application;
 	} action;
@@ -57,7 +65,7 @@ GnomeVFSMimeApplication *gnome_vfs_mime_application_copy                   (Gnom
 GnomeVFSMimeActionType   gnome_vfs_mime_get_default_action_type            (const char              *mime_type);
 GnomeVFSMimeAction *     gnome_vfs_mime_get_default_action                 (const char              *mime_type);
 GnomeVFSMimeApplication *gnome_vfs_mime_get_default_application            (const char              *mime_type);
-OAF_ServerInfo *         gnome_vfs_mime_get_default_component              (const char              *mime_type);
+Bonobo_ServerInfo *      gnome_vfs_mime_get_default_component              (const char              *mime_type);
 GList *                  gnome_vfs_mime_get_short_list_applications        (const char              *mime_type);
 GList *                  gnome_vfs_mime_get_short_list_components          (const char              *mime_type);
 GList *                  gnome_vfs_mime_get_all_applications               (const char              *mime_type);
@@ -68,10 +76,14 @@ GnomeVFSResult           gnome_vfs_mime_set_default_application            (cons
 									    const char              *application_id);
 GnomeVFSResult           gnome_vfs_mime_set_default_component              (const char              *mime_type,
 									    const char              *component_iid);
+
 const char  		*gnome_vfs_mime_get_icon 			   (const char 		    *mime_type);
 GnomeVFSResult  	 gnome_vfs_mime_set_icon 			   (const char 		    *mime_type,
 									    const char		    *filename);
 const char 	        *gnome_vfs_mime_get_description   		   (const char              *mime_type);
+GnomeVFSResult		 gnome_vfs_mime_set_description			   (const char		    *mime_type,
+									    const char		    *description);
+
 gboolean 	         gnome_vfs_mime_can_be_executable   		   (const char              *mime_type);
 GnomeVFSResult	 	 gnome_vfs_mime_set_can_be_executable   	   (const char              *mime_type,
 									    gboolean		     new_value);
@@ -80,14 +92,14 @@ GnomeVFSResult	 	 gnome_vfs_mime_set_can_be_executable   	   (const char
 GnomeVFSResult           gnome_vfs_mime_set_short_list_applications        (const char              *mime_type,
 									    GList                   *application_ids);
 GnomeVFSResult           gnome_vfs_mime_set_short_list_components          (const char              *mime_type,
-									    GList                   *component_ids);
-GnomeVFSResult           gnome_vfs_mime_add_application_to_short_list      (const char              *uri,
+									    GList                   *component_iids);
+GnomeVFSResult           gnome_vfs_mime_add_application_to_short_list      (const char              *mime_type,
 									    const char              *application_id);
-GnomeVFSResult           gnome_vfs_mime_remove_application_from_short_list (const char              *uri,
+GnomeVFSResult           gnome_vfs_mime_remove_application_from_short_list (const char              *mime_type,
 									    const char              *application_id);
-GnomeVFSResult           gnome_vfs_mime_add_component_to_short_list        (const char              *uri,
+GnomeVFSResult           gnome_vfs_mime_add_component_to_short_list        (const char              *mime_type,
 									    const char              *iid);
-GnomeVFSResult           gnome_vfs_mime_remove_component_from_short_list   (const char              *uri,
+GnomeVFSResult           gnome_vfs_mime_remove_component_from_short_list   (const char              *mime_type,
 									    const char              *iid);
 GnomeVFSResult           gnome_vfs_mime_add_extension                      (const char              *mime_type,
 									    const char              *extension);
@@ -121,4 +133,6 @@ GList *                  gnome_vfs_mime_remove_component_from_list         (GLis
 GList *                  gnome_vfs_mime_id_list_from_component_list        (GList                   *components);
 GList *                  gnome_vfs_mime_id_list_from_application_list      (GList                   *applications);
 
+G_END_DECLS
+
 #endif /* GNOME_VFS_MIME_HANDLERS_H */
